CREATE TABLE sa_remindinfo (
  SID varchar(32) NOT NULL,
  STITLE varchar(100),
  SCONTEXT varchar(1000),
  SDATETIME timestamp,
  SSTATE varchar(100),
  SACTION varchar(100),
  SPERSONID varchar(32),
  SPERSONNAME varchar(100),
  SORGID varchar(32),
  SORGNAME varchar(100),
  VERSION int,
  PRIMARY KEY (SID)
);

CREATE TABLE sa_log (
  SID varchar(32) NOT NULL,
  STYPENAME varchar(100) DEFAULT NULL,
  SDESCRIPTION text,
  SPROCESS varchar(2048) DEFAULT NULL,
  SPROCESSNAME varchar(2048) DEFAULT NULL,
  SACTIVITY varchar(100) DEFAULT NULL,
  SACTIVITYNAME varchar(2048) DEFAULT NULL,
  SACTION varchar(100) DEFAULT NULL,
  SACTIONNAME varchar(2048) DEFAULT NULL,
  SSTATUSNAME varchar(64) DEFAULT NULL,
  SCREATETIME timestamp NULL DEFAULT NULL,
  SCREATORFID varchar(2048) DEFAULT NULL,
  SCREATORFNAME varchar(2048) DEFAULT NULL,
  SCREATORPERSONID varchar(36) DEFAULT NULL,
  SCREATORPERSONNAME varchar(255) DEFAULT NULL,
  SCREATORPOSID varchar(36) DEFAULT NULL,
  SCREATORPOSNAME varchar(255) DEFAULT NULL,
  SCREATORDEPTID varchar(36) DEFAULT NULL,
  SCREATORDEPTNAME varchar(255) DEFAULT NULL,
  SCREATOROGNID varchar(36) DEFAULT NULL,
  SCREATOROGNNAME varchar(255) DEFAULT NULL,
  SIP varchar(32) DEFAULT NULL,
  VERSION decimal(10,0) DEFAULT NULL,
  SDEVICETYPE varchar(100) DEFAULT NULL,
  SOPERATINGSYSTEM varchar(100) DEFAULT NULL,
  PRIMARY KEY (SID)
);

CREATE TABLE sa_onlineinfo (
  SID varchar(32) NOT NULL,
  SUSERID varchar(36) DEFAULT NULL,
  SUSERNAME varchar(100) DEFAULT NULL,
  SUSERFID varchar(1024) DEFAULT NULL,
  SUSERFNAME varchar(1024) DEFAULT NULL,
  SLOGINIP varchar(100) DEFAULT NULL,
  SLOGINDATE timestamp DEFAULT NULL,
  SSESSIONID varchar(100) DEFAULT NULL,
  SSERVICEIP varchar(100) DEFAULT NULL,
  VERSION int DEFAULT NULL,
  SMACHINECODE varchar(100) DEFAULT NULL,
  PRIMARY KEY (SID)
);
CREATE INDEX SA_ONLINEINFO_SSESSIONID on sa_onlineinfo(SSESSIONID);
CREATE INDEX SA_ONLINEINFO_SSERVICEIP on sa_onlineinfo(SSERVICEIP);

CREATE TABLE sa_oppermission (
  SID varchar(32) NOT NULL,
  SPERMISSIONROLEID varchar(32) NOT NULL,
  SPROCESS varchar(1024) DEFAULT NULL,
  SACTIVITYFNAME varchar(1024) DEFAULT NULL,
  SACTIVITY varchar(1024) DEFAULT NULL,
  SACTIONSNAMES text,
  SACTIONS text,
  SSEMANTICDP varchar(2048) DEFAULT NULL,
  SPERMISSIONKIND int DEFAULT NULL,
  SDESCRIPTION varchar(1024) DEFAULT NULL,
  SSEQUENCE int DEFAULT NULL,
  SVALIDSTATE int DEFAULT NULL,
  VERSION int NOT NULL,
  PRIMARY KEY (SID)
);
CREATE INDEX IDX_OPPERM_ROLEID on sa_oppermission(SPERMISSIONROLEID);
CREATE INDEX IDX_OPPERM_ACTIVITY on sa_oppermission(SACTIVITY);
CREATE INDEX IDX_OPPERM_PROCESS on sa_oppermission(SPROCESS);

CREATE TABLE sa_opauthorize (
  SID varchar(100) NOT NULL,
  SORGID varchar(65) DEFAULT NULL,
  SORGNAME varchar(255) DEFAULT NULL,
  SORGFID varchar(2048) DEFAULT NULL,
  SORGFNAME varchar(2048) DEFAULT NULL,
  SAUTHORIZEROLEID varchar(32) DEFAULT NULL,
  SDESCRIPTION varchar(1024) DEFAULT NULL,
  SCREATORFID varchar(2048) DEFAULT NULL,
  SCREATORFNAME varchar(2048) DEFAULT NULL,
  SCREATETIME timestamp DEFAULT NULL,
  VERSION int DEFAULT NULL,
  SROLELEVEL varchar(100) DEFAULT NULL,
  PRIMARY KEY (SID)
);
CREATE INDEX IDX_OPAUTH_ROLEID on sa_opauthorize(SAUTHORIZEROLEID);

CREATE TABLE sa_opperson (
  SID varchar(36) NOT NULL,
  SNAME varchar(64) NOT NULL,
  SCODE varchar(64) NOT NULL,
  SIDCARD varchar(36) DEFAULT NULL,
  SNUMB int NOT NULL,
  SLOGINNAME varchar(64) DEFAULT NULL,
  SPASSWORD varchar(64) DEFAULT NULL,
  SPASSWORDTIMELIMIT int DEFAULT NULL,
  SPASSWORDMODIFYTIME timestamp DEFAULT NULL,
  SMAINORGID varchar(36) NOT NULL,
  SSAFELEVELID varchar(36) DEFAULT NULL,
  SSEQUENCE int DEFAULT NULL,
  SVALIDSTATE int DEFAULT NULL,
  SDESCRIPTION varchar(2048) DEFAULT NULL,
  SSEX varchar(8) DEFAULT NULL,
  SBIRTHDAY timestamp DEFAULT NULL,
  SJOINDATE timestamp DEFAULT NULL,
  SHOMEPLACE varchar(64) DEFAULT NULL,
  SDEGREE varchar(16) DEFAULT NULL,
  SGRADUATESCHOOL varchar(128) DEFAULT NULL,
  SSPECIALITY varchar(128) DEFAULT NULL,
  SSCHOOLLENGTH varchar(16) DEFAULT NULL,
  STITLE varchar(64) DEFAULT NULL,
  SMARRIAGE varchar(16) DEFAULT NULL,
  SCARDNO varchar(36) DEFAULT NULL,
  SCARDKIND varchar(64) DEFAULT NULL,
  SFAMILYADDRESS varchar(255) DEFAULT NULL,
  SZIP varchar(16) DEFAULT NULL,
  SMSN varchar(64) DEFAULT NULL,
  SQQ varchar(36) DEFAULT NULL,
  SMAIL varchar(64) DEFAULT NULL,
  SMOBILEPHONE varchar(36) DEFAULT NULL,
  SFAMILYPHONE varchar(36) DEFAULT NULL,
  SOFFICEPHONE varchar(36) DEFAULT NULL,
  VERSION int DEFAULT NULL,
  SPHOTO bytea,
  SCOUNTRY varchar(64) DEFAULT NULL,
  SPROVINCE varchar(64) DEFAULT NULL,
  SCITY varchar(64) DEFAULT NULL,
  SPOSITIONS varchar(64) DEFAULT NULL,
  SSCHOOL varchar(64) DEFAULT NULL,
  SSTUDY varchar(64) DEFAULT NULL,
  SENGLISHNAME varchar(128) DEFAULT NULL,
  FCASN varchar(100) DEFAULT NULL,
  FSIGNM varchar(100) DEFAULT NULL,
  PRIMARY KEY (SID)
);
CREATE INDEX IDX_OPPERSON_SCODE on sa_opperson(SCODE);
CREATE INDEX IDX_OPPERSON_SMAINORGID on sa_opperson(SMAINORGID);
CREATE INDEX XMSGINDEXMESSAGESVALIDSTATE on sa_opperson(SVALIDSTATE);

CREATE TABLE sa_opperson_deatail (
  SID varchar(36) NOT NULL,
  SPERSONID varchar(36) DEFAULT NULL,
  STYPE varchar(500) DEFAULT NULL,
  SSQUNS varchar(500) DEFAULT NULL,
  SCODE varchar(500) DEFAULT NULL,
  SNAME varchar(500) DEFAULT NULL,
  SREMARK varchar(500) DEFAULT NULL,
  SCLASS varchar(500) DEFAULT NULL,
  SUPDATEDATE timestamp NULL DEFAULT NULL,
  SUPDATORID varchar(36) DEFAULT NULL,
  SUPDATORNAME varchar(255) DEFAULT NULL,
  VERSION int DEFAULT NULL,
  PRIMARY KEY (SID)
);

CREATE TABLE sa_oporg (
  SID varchar(100) NOT NULL,
  SNAME varchar(128) NOT NULL,
  SCODE varchar(64) NOT NULL,
  SLONGNAME varchar(255) DEFAULT NULL,
  SFNAME varchar(1024) DEFAULT NULL,
  SFCODE varchar(2048) DEFAULT NULL,
  SFID varchar(1024) NOT NULL,
  SORGKINDID varchar(5) NOT NULL,
  SVALIDSTATE int DEFAULT NULL,
  SPARENT varchar(100) DEFAULT NULL,
  SLEVEL int DEFAULT NULL,
  SPHONE varchar(64) DEFAULT NULL,
  SFAX varchar(64) DEFAULT NULL,
  SADDRESS varchar(255) DEFAULT NULL,
  SZIP varchar(16) DEFAULT NULL,
  SDESCRIPTION varchar(1024) DEFAULT NULL,
  SPERSONID varchar(32) DEFAULT NULL,
  SNODEKIND varchar(32) DEFAULT NULL,
  VERSION int NOT NULL,
  SSHOWNAME varchar(100) DEFAULT NULL,
  SSEQUENCE int DEFAULT '1',
  PRIMARY KEY (SID)
);
CREATE INDEX SA_OPORG_SFID on sa_oporg(SFID);
CREATE INDEX IDX_OPORG_CODE on sa_oporg(SCODE);
CREATE INDEX IDX_SA_OPORG_SORGKINDID on sa_oporg(SORGKINDID);
CREATE INDEX IDX_SA_OPORG_SPARENT on sa_oporg(SPARENT);
CREATE INDEX IDX_SA_OPORG_SPERSONID on sa_oporg(SPERSONID);

CREATE TABLE sa_oporg_interface (
  SOGNID varchar(36) NOT NULL,
  SOGNNAME varchar(200) DEFAULT NULL,
  PRIMARY KEY (SOGNID)
);

CREATE TABLE sa_oprole (
  SID varchar(32) NOT NULL,
  SNAME varchar(255),
  SCODE varchar(32),
  SCATALOG varchar(128),
  SROLEKIND varchar(32),
  SPARENTROLESNAMES varchar(512),
  SDESCRIPTION varchar(1024),
  SSEQUENCE int,
  SVALIDSTATE int,
  VERSION int NOT NULL,
  PRIMARY KEY (SID)
);
CREATE INDEX IDX_OPROLE_CODE on sa_oprole(SCODE);

CREATE TABLE sa_oprolemanage (
  SID varchar(36) NOT NULL,
  SORGID varchar(36),
  SORGFID varchar(360),
  SPERSONID varchar(36),
  SROLEID varchar(36),
  SCREATORID varchar(36),
  SCREATETIME timestamp,
  VERSION int,
  PRIMARY KEY (SID)
);

CREATE TABLE sa_oprolemanagement (
  SID varchar(35) NOT NULL,
  SORGID varchar(80) NOT NULL,
  SORGNAME varchar(255),
  SORGFID varchar(2048) NOT NULL,
  SORGFNAME varchar(2048),
  SROLEID varchar(35) NOT NULL,
  SCREATORFID varchar(2048),
  SCREATORFNAME varchar(2048),
  SCREATETIME timestamp,
  VERSION int NOT NULL,
  PRIMARY KEY (SID)
);

create table SA_PORTALLETS
(
  SPERSONID    VARCHAR(100) not null,
  SLAYOUTSET   VARCHAR(1024),
  SPANLES      TEXT,
  SCREATORID   VARCHAR(100),
  SCREATORNAME VARCHAR(100),
  SCREATEDATE  timestamp,
  PRIMARY KEY (SPERSONID)
);

CREATE TABLE sa_oprolerole (
  SID varchar(36) NOT NULL,
  SROLEID varchar(36) NOT NULL,
  SPARENTROLE varchar(36) NOT NULL,
  VERSION int,
  PRIMARY KEY (SID)
);

CREATE TABLE sa_portalprofiles (
  SID varchar(100) NOT NULL,
  VERSION decimal(10,0),
  SNAME varchar(100),
  SPERSONID varchar(100),
  SVALUE text,
  PRIMARY KEY (SID)
);

CREATE TABLE sa_portelinfo (
  SID varchar(100) NOT NULL,
  STHEMETYPE varchar(10),
  SPSNDESKINFO text,
  SPERSONID varchar(100),
  PRIMARY KEY (SID)
);

CREATE TABLE sa_task (
  SID varchar(36) NOT NULL,
  SPARENTID varchar(36) DEFAULT NULL,
  SNAME varchar(255) DEFAULT NULL,
  SCONTENT text,
  SREMARK text,
  SFLOWID varchar(36) DEFAULT NULL,
  STYPEID varchar(36) DEFAULT NULL,
  STYPENAME varchar(64) DEFAULT NULL,
  SIMPORTANCEID varchar(36) DEFAULT NULL,
  SIMPORTANCENAME varchar(64) DEFAULT NULL,
  SEMERGENCYID varchar(36) DEFAULT NULL,
  SEMERGENCYNAME varchar(64) DEFAULT NULL,
  SPROCESS varchar(255) DEFAULT NULL,
  SACTIVITY varchar(255) DEFAULT NULL,
  SCREATETIME timestamp DEFAULT NULL,
  SDISTRIBUTETIME timestamp DEFAULT NULL,
  SLASTMODIFYTIME timestamp DEFAULT NULL,
  SWARNINGTIME timestamp DEFAULT NULL,
  SLIMITTIME timestamp DEFAULT NULL,
  SESTARTTIME timestamp DEFAULT NULL,
  SEFINISHTIME timestamp DEFAULT NULL,
  SASTARTTIME timestamp DEFAULT NULL,
  SAFINISHTIME timestamp DEFAULT NULL,
  SEXECUTETIME timestamp DEFAULT NULL,
  SCPERSONID varchar(36) DEFAULT NULL,
  SCPERSONNAME varchar(255) DEFAULT NULL,
  SCDEPTID varchar(36) DEFAULT NULL,
  SCDEPTNAME varchar(255) DEFAULT NULL,
  SCOGNID varchar(36) DEFAULT NULL,
  SCOGNNAME varchar(255) DEFAULT NULL,
  SEPERSONID varchar(36) DEFAULT NULL,
  SEPERSONNAME varchar(255) DEFAULT NULL,
  SEDEPTID varchar(36) DEFAULT NULL,
  SEDEPTNAME varchar(255) DEFAULT NULL,
  SEOGNID varchar(36) DEFAULT NULL,
  SEOGNNAME varchar(255) DEFAULT NULL,
  SCUSTOMERID varchar(64) DEFAULT NULL,
  SCUSTOMERNAME varchar(255) DEFAULT NULL,
  SPROJECTID varchar(64) DEFAULT NULL,
  SPROJECTNAME varchar(255) DEFAULT NULL,
  SPLANID varchar(64) DEFAULT NULL,
  SPLANNAME varchar(255) DEFAULT NULL,
  SVARIABLE text,
  SFAKE varchar(8) DEFAULT NULL,
  SACTIVE varchar(8) DEFAULT NULL,
  SLOCK varchar(36) DEFAULT NULL,
  SSTATUSID varchar(36) DEFAULT NULL,
  SSTATUSNAME varchar(64) DEFAULT NULL,
  VERSION int DEFAULT NULL,
  SAIID varchar(36) DEFAULT NULL,
  SCATALOGID varchar(36) DEFAULT NULL,
  SKINDID varchar(36) DEFAULT NULL,
  SAIACTIVE varchar(8) DEFAULT NULL,
  SAISTATUSID varchar(255) DEFAULT NULL,
  SAISTATUSNAME varchar(255) DEFAULT NULL,
  SSOURCEID varchar(36) DEFAULT NULL,
  SCURL varchar(255) DEFAULT NULL,
  SEURL varchar(255) DEFAULT NULL,
  SEXECUTEMODE varchar(32) DEFAULT NULL,
  SEXECUTEMODE2 varchar(255) DEFAULT NULL,
  SPREEMPTMODE varchar(32) DEFAULT NULL,
  SSEQUENCE int DEFAULT NULL,
  SCPERSONCODE varchar(64) DEFAULT NULL,
  SCPOSID varchar(36) DEFAULT NULL,
  SCPOSCODE varchar(64) DEFAULT NULL,
  SCPOSNAME varchar(255) DEFAULT NULL,
  SCDEPTCODE varchar(64) DEFAULT NULL,
  SCOGNCODE varchar(64) DEFAULT NULL,
  SCFID varchar(1024) DEFAULT NULL,
  SEPERSONCODE varchar(64) DEFAULT NULL,
  SEPOSID varchar(36) DEFAULT NULL,
  SEPOSCODE varchar(64) DEFAULT NULL,
  SEPOSNAME varchar(255) DEFAULT NULL,
  SEDEPTCODE varchar(64) DEFAULT NULL,
  SEOGNCODE varchar(64) DEFAULT NULL,
  SEFID varchar(1024) DEFAULT NULL,
  SEXECUTORNAMES varchar(255) DEFAULT NULL,
  SRESPONSIBLE varchar(8) DEFAULT NULL,
  SCUSTOMERCODE varchar(64) DEFAULT NULL,
  SPROJECTCODE varchar(64) DEFAULT NULL,
  SPLANCODE varchar(64) DEFAULT NULL,
  SDATA1 varchar(128) DEFAULT NULL,
  SDATA2 varchar(128) DEFAULT NULL,
  SDATA3 varchar(128) DEFAULT NULL,
  SDATA4 varchar(128) DEFAULT NULL,
  SWORKTIME int DEFAULT NULL,
  SCFNAME varchar(255) DEFAULT NULL,
  SEFNAME varchar(255) DEFAULT NULL,
  SHINTS varchar(1024) DEFAULT NULL,
  SSHORTCUT varchar(1024) DEFAULT NULL,
  SFRONTID varchar(36) DEFAULT NULL,
  SFMAKERNAME varchar(100) DEFAULT NULL,
  PRIMARY KEY (SID)
);
CREATE INDEX SA_FLOWID on sa_task(SFLOWID);
CREATE INDEX SA_STATUS on sa_task(SSTATUSID);
CREATE INDEX SA_TASK_SPROCESS on sa_task(SPROCESS);
CREATE INDEX SA_TASK_SDATA_1 on sa_task(SDATA1);
CREATE INDEX SA_TASK_SPARENTID on sa_task(SPARENTID);

CREATE TABLE sa_task_history (
  SID varchar(36) NOT NULL,
  SPARENTID varchar(36) DEFAULT NULL,
  SNAME varchar(255) DEFAULT NULL,
  SCONTENT text,
  SREMARK text,
  SFLOWID varchar(36) DEFAULT NULL,
  STYPEID varchar(36) DEFAULT NULL,
  STYPENAME varchar(64) DEFAULT NULL,
  SIMPORTANCEID varchar(36) DEFAULT NULL,
  SIMPORTANCENAME varchar(64) DEFAULT NULL,
  SEMERGENCYID varchar(36) DEFAULT NULL,
  SEMERGENCYNAME varchar(64) DEFAULT NULL,
  SPROCESS varchar(255) DEFAULT NULL,
  SACTIVITY varchar(255) DEFAULT NULL,
  SCREATETIME timestamp DEFAULT NULL,
  SDISTRIBUTETIME timestamp DEFAULT NULL,
  SLASTMODIFYTIME timestamp DEFAULT NULL,
  SWARNINGTIME timestamp DEFAULT NULL,
  SLIMITTIME timestamp DEFAULT NULL,
  SESTARTTIME timestamp DEFAULT NULL,
  SEFINISHTIME timestamp DEFAULT NULL,
  SASTARTTIME timestamp DEFAULT NULL,
  SAFINISHTIME timestamp DEFAULT NULL,
  SEXECUTETIME timestamp DEFAULT NULL,
  SCPERSONID varchar(36) DEFAULT NULL,
  SCPERSONNAME varchar(255) DEFAULT NULL,
  SCDEPTID varchar(36) DEFAULT NULL,
  SCDEPTNAME varchar(255) DEFAULT NULL,
  SCOGNID varchar(36) DEFAULT NULL,
  SCOGNNAME varchar(255) DEFAULT NULL,
  SEPERSONID varchar(36) DEFAULT NULL,
  SEPERSONNAME varchar(255) DEFAULT NULL,
  SEDEPTID varchar(36) DEFAULT NULL,
  SEDEPTNAME varchar(255) DEFAULT NULL,
  SEOGNID varchar(36) DEFAULT NULL,
  SEOGNNAME varchar(255) DEFAULT NULL,
  SCUSTOMERID varchar(64) DEFAULT NULL,
  SCUSTOMERNAME varchar(255) DEFAULT NULL,
  SPROJECTID varchar(64) DEFAULT NULL,
  SPROJECTNAME varchar(255) DEFAULT NULL,
  SPLANID varchar(64) DEFAULT NULL,
  SPLANNAME varchar(255) DEFAULT NULL,
  SVARIABLE text,
  SFAKE varchar(8) DEFAULT NULL,
  SACTIVE varchar(8) DEFAULT NULL,
  SLOCK varchar(36) DEFAULT NULL,
  SSTATUSID varchar(36) DEFAULT NULL,
  SSTATUSNAME varchar(64) DEFAULT NULL,
  VERSION int DEFAULT NULL,
  SAIID varchar(36) DEFAULT NULL,
  SCATALOGID varchar(36) DEFAULT NULL,
  SKINDID varchar(36) DEFAULT NULL,
  SAIACTIVE varchar(8) DEFAULT NULL,
  SAISTATUSID varchar(255) DEFAULT NULL,
  SAISTATUSNAME varchar(255) DEFAULT NULL,
  SSOURCEID varchar(36) DEFAULT NULL,
  SCURL varchar(255) DEFAULT NULL,
  SEURL varchar(255) DEFAULT NULL,
  SEXECUTEMODE varchar(32) DEFAULT NULL,
  SEXECUTEMODE2 varchar(255) DEFAULT NULL,
  SPREEMPTMODE varchar(32) DEFAULT NULL,
  SSEQUENCE int DEFAULT NULL,
  SCPERSONCODE varchar(64) DEFAULT NULL,
  SCPOSID varchar(36) DEFAULT NULL,
  SCPOSCODE varchar(64) DEFAULT NULL,
  SCPOSNAME varchar(255) DEFAULT NULL,
  SCDEPTCODE varchar(64) DEFAULT NULL,
  SCOGNCODE varchar(64) DEFAULT NULL,
  SCFID varchar(1024) DEFAULT NULL,
  SEPERSONCODE varchar(64) DEFAULT NULL,
  SEPOSID varchar(36) DEFAULT NULL,
  SEPOSCODE varchar(64) DEFAULT NULL,
  SEPOSNAME varchar(255) DEFAULT NULL,
  SEDEPTCODE varchar(64) DEFAULT NULL,
  SEOGNCODE varchar(64) DEFAULT NULL,
  SEFID varchar(1024) DEFAULT NULL,
  SEXECUTORNAMES varchar(255) DEFAULT NULL,
  SRESPONSIBLE varchar(8) DEFAULT NULL,
  SCUSTOMERCODE varchar(64) DEFAULT NULL,
  SPROJECTCODE varchar(64) DEFAULT NULL,
  SPLANCODE varchar(64) DEFAULT NULL,
  SDATA1 varchar(128) DEFAULT NULL,
  SDATA2 varchar(128) DEFAULT NULL,
  SDATA3 varchar(128) DEFAULT NULL,
  SDATA4 varchar(128) DEFAULT NULL,
  SWORKTIME int DEFAULT NULL,
  SCFNAME varchar(255) DEFAULT NULL,
  SEFNAME varchar(255) DEFAULT NULL,
  SHINTS varchar(1024) DEFAULT NULL,
  SSHORTCUT varchar(1024) DEFAULT NULL,
  SFRONTID varchar(36) DEFAULT NULL,
  SFMAKERNAME varchar(100) DEFAULT NULL,
  PRIMARY KEY (SID)
);

CREATE TABLE sa_tasktype (
  SID varchar(50) NOT NULL,
  SNAME varchar(500) DEFAULT NULL,
  SCONCEPT varchar(500) DEFAULT NULL,
  SNEWACTIVITY varchar(500) DEFAULT NULL,
  SEXECUTEACTIVITY varchar(500) DEFAULT NULL,
  SKIND varchar(500) DEFAULT NULL,
  VERSION decimal(10,0) DEFAULT NULL,
  PRIMARY KEY (SID)
);

CREATE TABLE sa_task_timelimit (
  SID varchar(32) NOT NULL,
  SPROCESSID varchar(255) DEFAULT NULL,
  SPROCESSNAME varchar(512) DEFAULT NULL,
  SACTIVITY varchar(255) DEFAULT NULL,
  SACTIVITYNAME varchar(512) DEFAULT NULL,
  SDLIMIT int DEFAULT NULL,
  VERSION int DEFAULT NULL,
  PRIMARY KEY (SID)
);

CREATE TABLE sa_worklog (
  SID varchar(32) NOT NULL,
  SLOCK varchar(100) DEFAULT NULL,
  SNAME varchar(100) DEFAULT NULL,
  SCUSTOMERNAME varchar(100) DEFAULT NULL,
  SIMPORTANCENAME varchar(100) DEFAULT NULL,
  SPLANNAME varchar(100) DEFAULT NULL,
  SPROJECTNAME varchar(100) DEFAULT NULL,
  SEMERGENCYNAME varchar(100) DEFAULT NULL,
  SLIMITTIME timestamp DEFAULT NULL,
  SCONTENT text,
  SCREATORFID varchar(1024) DEFAULT NULL,
  SCREATOFNAME varchar(1024) DEFAULT NULL,
  SCREATETIME timestamp NULL DEFAULT NULL,
  FEXTEND01 varchar(100) DEFAULT NULL,
  VERSION int DEFAULT NULL,
  PRIMARY KEY (SID)
);

CREATE TABLE cyea_news_release (
  SID varchar(32) NOT NULL,
  VERSION int DEFAULT NULL,
  FNEWSTITLE varchar(200) DEFAULT NULL,
  FRELEASEDEPARTMENT varchar(100) DEFAULT NULL,
  FPEOPLE varchar(50) DEFAULT NULL,
  FTIME timestamp DEFAULT NULL,
  FNEWSNUMBER varchar(100) DEFAULT NULL,
  FRELEASECONNEXT text,
  FSTATE varchar(20) DEFAULT NULL,
  FSETTOPWHETHER varchar(10) DEFAULT NULL,
  FSETTOPTIME timestamp DEFAULT NULL,
  FSETENDTIME timestamp DEFAULT NULL,
  FACCESSORIES varchar(1024) DEFAULT NULL,
  FCOLUMNNAME varchar(100) DEFAULT NULL,
  FOPENSCOPE varchar(4000) DEFAULT NULL,
  FOPENSCOPEID varchar(4000) DEFAULT NULL,
  SMINIPIC bytea,
  PRIMARY KEY (SID)
);

CREATE TABLE cyea_news_count (
  SID varchar(100) NOT NULL,
  NEWS_NUMBER int DEFAULT '0',
  NEWS_PERSON varchar(100) DEFAULT NULL,
  NEWS_PERSONID varchar(100) DEFAULT NULL,
  NEWS_RELEASEID varchar(100) DEFAULT NULL,
  YETPERSON varchar(100) DEFAULT NULL,
  YETPERSONID varchar(100) DEFAULT NULL,
  VERSION int DEFAULT NULL,
  PRIMARY KEY (SID)
);

CREATE TABLE cyea_newscolumn (
  SID varchar(32) NOT NULL,
  VERSION int DEFAULT NULL,
  FCOLUMNCODE varchar(100) DEFAULT NULL,
  FCOLUMNNAME varchar(100) DEFAULT NULL,
  FCOLUMNDESCRIBES varchar(100) DEFAULT NULL,
  FCOLUMNSTATE varchar(50) DEFAULT NULL,
  PRIMARY KEY (SID)
);

CREATE TABLE sa_docauth (
  SID varchar(36) NOT NULL,
  SDOCPATH TEXT DEFAULT NULL,
  SAUTHORIZERFID varchar(512) DEFAULT NULL,
  SAUTHORIZERNAME varchar(64) DEFAULT NULL,
  SAUTHORIZERDEPTNAME varchar(64) DEFAULT NULL,
  SAUTHORIZEEFID varchar(512) DEFAULT NULL,
  SAUTHORIZEENAME varchar(64) DEFAULT NULL,
  SGRANTTIME timestamp DEFAULT NULL,
  SACCESS int DEFAULT NULL,
  SSCOPE varchar(16) DEFAULT NULL,
  SAUTHORIZEEDEPTNAME varchar(64) DEFAULT NULL,
  VERSION decimal(10,0) DEFAULT NULL,
  PRIMARY KEY (SID)
);

CREATE TABLE sa_docnamespace (
  SID varchar(128) NOT NULL,
  SDISPLAYNAME varchar(256) DEFAULT NULL,
  SHOST varchar(128) DEFAULT NULL,
  SPORT int DEFAULT NULL,
  SURL varchar(128) DEFAULT NULL,
  VERSION int DEFAULT NULL,
  SFLAG int DEFAULT NULL,
  SACCESSMODE varchar(64) DEFAULT NULL,
  PRIMARY KEY (SID)
);

CREATE TABLE sa_docnode (
  SID varchar(36) NOT NULL,
  SPARENTID varchar(36) DEFAULT NULL,
  SDOCNAME varchar(2500) DEFAULT NULL,
  SSEQUENCE varchar(128) DEFAULT NULL,
  SSIZE float DEFAULT NULL,
  SKIND varchar(128) DEFAULT NULL,
  SDOCPATH TEXT DEFAULT NULL,
  SDOCDISPLAYPATH text,
  SCREATORFID varchar(2048) DEFAULT NULL,
  SCREATORNAME varchar(64) DEFAULT NULL,
  SCREATORDEPTNAME varchar(64) DEFAULT NULL,
  SCREATETIME timestamp DEFAULT NULL,
  SEDITORFID varchar(2048) DEFAULT NULL,
  SEDITORNAME varchar(64) DEFAULT NULL,
  SEDITORDEPTNAME varchar(64) DEFAULT NULL,
  SLASTWRITERFID varchar(2048) DEFAULT NULL,
  SLASTWRITERNAME varchar(64) DEFAULT NULL,
  SLASTWRITERDEPTNAME varchar(64) DEFAULT NULL,
  SLASTWRITETIME timestamp DEFAULT NULL,
  SFILEID varchar(128) DEFAULT NULL,
  SDESCRIPTION text,
  SDOCLIVEVERSIONID int DEFAULT NULL,
  VERSION decimal(10,0) DEFAULT NULL,
  SCLASSIFICATION varchar(128) DEFAULT NULL,
  SKEYWORDS varchar(256) DEFAULT NULL,
  SDOCSERIALNUMBER varchar(128) DEFAULT NULL,
  SFINISHTIME timestamp DEFAULT NULL,
  SNAMESPACE varchar(256) DEFAULT NULL,
  SCACHENAME varchar(100) DEFAULT NULL,
  SREVISIONCACHENAME varchar(100) DEFAULT NULL,
  SFLAG int DEFAULT NULL,
  PRIMARY KEY (SID)
);
CREATE INDEX IDX_SA_DOCNODE on sa_docnode(SPARENTID);
CREATE INDEX IND_SA_DONNODE_SKIND on sa_docnode(SKIND);
CREATE INDEX IDX_SA_DOCNODE_SFILEID on sa_docnode(SFILEID);

create table SA_DOCLOG
(
  SID           VARCHAR(36) not null,
  SPERSONNAME   VARCHAR(64),
  SACCESSTYPE   VARCHAR(16),
  SDOCID        VARCHAR(64),
  STIME         timestamp,
  SDEPTNAME     VARCHAR(64),
  SPERSONFID    VARCHAR(512),
  SDOCVERSIONID INT,
  SDOCNAME      VARCHAR(128),
  SSIZE         FLOAT,
  VERSION       INT,
  PRIMARY KEY (SID)
);

CREATE TABLE sa_flowcontrol (
  SID varchar(36) NOT NULL,
  SOPERATORID varchar(50) DEFAULT NULL,
  SPROCESS varchar(255) DEFAULT NULL,
  SACTIVITY varchar(255) DEFAULT NULL,
  SACTION varchar(36) DEFAULT NULL,
  SKIND varchar(16) DEFAULT NULL,
  SCONTENT text,
  VERSION int DEFAULT NULL,
  PRIMARY KEY (SID)
);

CREATE TABLE sa_flowdata (
  SID varchar(36) NOT NULL,
  SFLOWID varchar(36) DEFAULT NULL,
  SPROCESS varchar(36) DEFAULT NULL,
  SACTIVITY varchar(255) DEFAULT NULL,
  SACTION varchar(255) DEFAULT NULL,
  SKIND varchar(36) DEFAULT NULL,
  SCONTENT text,
  VERSION int DEFAULT NULL,
  PRIMARY KEY (SID)
);

CREATE TABLE sa_flowdrawlg (
  SID varchar(32) NOT NULL,
  SPROCESSID varchar(100) NOT NULL,
  SPROCESSNAME varchar(100),
  SDRAWLG text,
  VERSION int DEFAULT 0,
  SPROCESSACTY text,
  SCREATORID varchar(100),
  SCREATORNAME varchar(100),
  SUPDATORID varchar(100),
  SUPDATORNAME varchar(100),
  SCREATETIME timestamp,
  SUPDATETIME timestamp,
  FENABLED int, 
  SFOLDERID varchar(32),
  PRIMARY KEY (SID)
);
CREATE INDEX SA_FLOWDRAWLG_SPROCESSID on sa_flowdrawlg(SPROCESSID);

CREATE TABLE sa_flowdrawlg_ipo (
  SID varchar(32) NOT NULL,
  SPROCESSID varchar(100) NOT NULL,
  SPROCESSNAME varchar(100) DEFAULT NULL,
  SDRAWLG text,
  VERSION int DEFAULT NULL,
  SPROCESSACTY text,
  SCREATORID varchar(100) DEFAULT NULL,
  SCREATORNAME varchar(100) DEFAULT NULL,
  SUPDATORID varchar(100) DEFAULT NULL,
  SUPDATORNAME varchar(100) DEFAULT NULL,
  SCREATETIME timestamp DEFAULT NULL,
  SUPDATETIME timestamp DEFAULT NULL,
  FENABLED int DEFAULT NULL,
  PRIMARY KEY (SID)
);

CREATE TABLE sa_flowfolder (
  SID varchar(32) NOT NULL,
  SPROCESSID varchar(100) DEFAULT NULL,
  SPROCESSNAME varchar(100) DEFAULT NULL,
  SCODE varchar(100) DEFAULT NULL,
  SNAME varchar(100) DEFAULT NULL,
  SPARENT varchar(32) DEFAULT NULL,
  SIDPATH varchar(4000) DEFAULT NULL,
  SNAMEPATH varchar(4000) DEFAULT NULL,
  SCODEPATH varchar(4000) DEFAULT NULL,
  VERSION int NOT NULL DEFAULT '0',
  PRIMARY KEY (SID)
);
CREATE INDEX SOU_SA_FLWFOLDER_SPARENT on sa_flowfolder(SPARENT);

CREATE TABLE sa_flowinfo (
  ID varchar(32) NOT NULL,
  STOACTIVITY varchar(500) DEFAULT NULL,
  STOOPERATORID varchar(4000) DEFAULT NULL,
  VERSION decimal DEFAULT NULL,
  SFROMACTIVITYINSTANCEID varchar(500) DEFAULT NULL,
  STASKNAME varchar(500) DEFAULT NULL,
  STASKCONTENT varchar(500) DEFAULT NULL,
  STASKCREATETIME timestamp DEFAULT NULL,
  STASKEMERGENCYID decimal DEFAULT NULL,
  STASKWARNINGTIME timestamp DEFAULT NULL,
  STASKLIMITTIME timestamp DEFAULT NULL,
  PRIMARY KEY (ID)
);

CREATE TABLE sa_flowinfoext (
  ID varchar(100) NOT NULL,
  SPROCESS varchar(200) NOT NULL,
  SFROMACTIVITY varchar(200) NOT NULL,
  SCREATORID varchar(50) DEFAULT NULL,
  SEXECUTORS text,
  STOACTIVITY varchar(500) DEFAULT NULL,
  VERSION decimal(10,0) DEFAULT NULL,
  PRIMARY KEY (ID)
);

CREATE TABLE sa_flowtrace (
  SID varchar(36) NOT NULL,
  SOPERATORID varchar(36) DEFAULT NULL,
  SOPERATORCODE varchar(100) DEFAULT NULL,
  SOPERATORNAME varchar(100) DEFAULT NULL,
  SCURL varchar(1024) DEFAULT NULL,
  SEURL varchar(1024) DEFAULT NULL,
  SCHECKPSN varchar(4000) DEFAULT NULL,
  VERSION int NOT NULL,
  PRIMARY KEY (SID)
);
CREATE INDEX SA_FLOWTRACE_SOPERATORID on sa_flowtrace(SOPERATORID);
CREATE INDEX SA_FLOWTRACE_SEURL on sa_flowtrace(SEURL);

CREATE TABLE sa_kvsequence (
  K varchar(200) NOT NULL,
  V int NOT NULL,
  PRIMARY KEY (K)
);

CREATE TABLE sa_links (
  SID varchar(32) DEFAULT NULL,
  STITLE varchar(100) DEFAULT NULL,
  SURL varchar(1024) DEFAULT NULL,
  SUSERNAME varchar(100) DEFAULT NULL,
  SPASSWORD varchar(100) DEFAULT NULL,
  SEXPARAMS varchar(1024) DEFAULT NULL,
  SOPENTYPE varchar(20) DEFAULT NULL,
  SCREATID varchar(100) DEFAULT NULL,
  SCREATER varchar(100) DEFAULT NULL,
  SCREATEDATE timestamp DEFAULT NULL,
  VERSION int DEFAULT NULL
);

CREATE TABLE sa_loginlog (
  SID varchar(32) NOT NULL,
  SUSERID varchar(36) DEFAULT NULL,
  SUSERNAME varchar(100) DEFAULT NULL,
  SLOGINIP varchar(100) DEFAULT NULL,
  SLOGINTIME timestamp DEFAULT NULL,
  PASSWORD varchar(100) DEFAULT NULL,
  VERSION int DEFAULT NULL,
  SSERVICEIP varchar(100) DEFAULT NULL,
  SDAY varchar(100) DEFAULT NULL,
  SDAYNUM int DEFAULT NULL,
  PRIMARY KEY (SID)
);

CREATE TABLE sa_online_log (
  SID varchar(32) NOT NULL,
  SUSERID varchar(36) DEFAULT NULL,
  SUSERNAME varchar(100) DEFAULT NULL,
  SUSERFID varchar(1024) DEFAULT NULL,
  SUSERFNAME varchar(1024) DEFAULT NULL,
  SLOGINIP varchar(100) DEFAULT NULL,
  SLOGINDATE timestamp DEFAULT NULL,
  SLOGOUTDATE timestamp DEFAULT NULL,
  SSESSIONID varchar(100) DEFAULT NULL,
  SSERVICEIP varchar(100) DEFAULT NULL,
  VERSION int DEFAULT NULL,
  SDAY varchar(100) DEFAULT NULL,
  SDAYNUM int DEFAULT NULL,
  PRIMARY KEY (SID)
);
CREATE INDEX SA_PNLINE_LOG_SLOGINDATE on sa_online_log(SLOGINDATE);
CREATE INDEX SA_ONLINE_LOG_SSERVICEIP on sa_online_log(SSERVICEIP);
CREATE INDEX SA_ONLINE_LOG_SSESSIONID on sa_online_log(SSESSIONID);

CREATE TABLE sa_opagent (
  SID varchar(32) NOT NULL,
  SORGFID varchar(2048) NOT NULL,
  SORGFNAME varchar(2048) NOT NULL,
  SAGENTID varchar(32) NOT NULL,
  SVALIDSTATE int DEFAULT NULL,
  SSTARTTIME timestamp DEFAULT NULL,
  SFINISHTIME timestamp DEFAULT NULL,
  SPROCESS text,
  SCREATORID varchar(32) DEFAULT NULL,
  SCREATORNAME varchar(64) DEFAULT NULL,
  SCREATETIME timestamp DEFAULT NULL,
  SCANTRANAGENT int DEFAULT NULL,
  VERSION int NOT NULL,
  PRIMARY KEY (SID)
);

CREATE TABLE sa_opmanagement (
  SID varchar(32) NOT NULL,
  SORGID varchar(65) NOT NULL,
  SORGNAME varchar(255) DEFAULT NULL,
  SORGFID varchar(2048) NOT NULL,
  SORGFNAME varchar(2048) DEFAULT NULL,
  SMANAGEORGID varchar(65) NOT NULL,
  SMANAGEORGNAME varchar(255) DEFAULT NULL,
  SMANAGEORGFID varchar(2048) NOT NULL,
  SMANAGEORGFNAME varchar(2048) DEFAULT NULL,
  SMANAGETYPEID varchar(32) NOT NULL,
  SCREATORFID varchar(2048) DEFAULT NULL,
  SCREATORFNAME varchar(2048) DEFAULT NULL,
  SCREATETIME timestamp DEFAULT NULL,
  VERSION int NOT NULL,
  PRIMARY KEY (SID)
);

CREATE TABLE sa_opmanagetype (
  SID varchar(32) NOT NULL,
  SNAME varchar(255) DEFAULT NULL,
  SCODE varchar(32) DEFAULT NULL,
  SMANAGEORGKIND varchar(64) DEFAULT NULL,
  SMANAGEORGKINDNAME varchar(255) DEFAULT NULL,
  SLEADERNUMBER int DEFAULT NULL,
  SISSYSTEM int DEFAULT NULL,
  VERSION int NOT NULL,
  PRIMARY KEY (SID)
);

CREATE TABLE sa_opmobilelog (
  SID varchar(32) NOT NULL,
  SUSERID varchar(100) DEFAULT NULL,
  SUSERNAME varchar(100) DEFAULT NULL,
  SIP varchar(100) DEFAULT NULL,
  SDATE timestamp DEFAULT NULL,
  SMODE varchar(100) DEFAULT NULL,
  VERSION int DEFAULT NULL,
  SSESSIONID varchar(100) DEFAULT NULL,
  SLOGOUTDATE timestamp DEFAULT NULL,
  PRIMARY KEY (SID)
);

CREATE TABLE sa_mailset (
  sid varchar(32) NOT NULL,
  smail varchar(100),
  saccount varchar(100),
  sname varchar(200),
  stype varchar(20),
  ssendhost varchar(100),
  ssendpost varchar(10),
  sisssl varchar(10),
  srechost varchar(100),
  srecport varchar(20),
  srecssl varchar(10),
  sispub varchar(10),
  fcreatepsnfid varchar(2048),
  fcreatepsnid varchar(36),
  fcreatepsnname varchar(100),
  fcreatedeptid varchar(36),
  fcreatedeptname varchar(200),
  fcreateognid varchar(36),
  fcreateognname varchar(200),
  fcreateorgid varchar(36),
  fcreateorgname varchar(200),
  fcreatetime timestamp(6),
  version int4
);
COMMENT ON COLUMN sa_mailset.smail IS '邮箱地址';
COMMENT ON COLUMN sa_mailset.saccount IS '密码';
COMMENT ON COLUMN sa_mailset.sname IS '发信名称';
COMMENT ON COLUMN sa_mailset.stype IS '邮箱类型';
COMMENT ON COLUMN sa_mailset.ssendhost IS '发件服务器';
COMMENT ON COLUMN sa_mailset.ssendpost IS '发件端口';
COMMENT ON COLUMN sa_mailset.sisssl IS '发件是否启用SSL';
COMMENT ON COLUMN sa_mailset.srechost IS '收件服务器';
COMMENT ON COLUMN sa_mailset.srecport IS '收件端口';
COMMENT ON COLUMN sa_mailset.srecssl IS '收件是否启用SSL';
COMMENT ON COLUMN sa_mailset.sispub IS '是否公用';
COMMENT ON COLUMN sa_mailset.fcreatepsnfid IS '创建人FID';
COMMENT ON COLUMN sa_mailset.fcreatepsnid IS '创建人ID';
COMMENT ON COLUMN sa_mailset.fcreatepsnname IS '创建人名称';
COMMENT ON COLUMN sa_mailset.fcreatedeptid IS '部门ID';
COMMENT ON COLUMN sa_mailset.fcreatedeptname IS '部门名称';
COMMENT ON COLUMN sa_mailset.fcreateognid IS '机构ID';
COMMENT ON COLUMN sa_mailset.fcreateognname IS '机构名称';
COMMENT ON COLUMN sa_mailset.fcreateorgid IS '组织ID';
COMMENT ON COLUMN sa_mailset.fcreateorgname IS '组织名称';
COMMENT ON COLUMN sa_mailset.fcreatetime IS '创建时间';

CREATE TABLE im_message (
  sID varchar(32) NOT NULL,
  favatar varchar(1000) DEFAULT NULL,
  fusername varchar(100) DEFAULT NULL,
  fid varchar(100) DEFAULT NULL,
  content text,
  tavatar varchar(1000) DEFAULT NULL,
  tname varchar(100) DEFAULT NULL,
  tsign varchar(500) DEFAULT NULL,
  stype varchar(100) DEFAULT NULL,
  tusername varchar(100) DEFAULT NULL,
  state int DEFAULT NULL,
  stime timestamp DEFAULT NULL,
  VERSION int DEFAULT NULL,
  groupname varchar(100) DEFAULT NULL,
  tid varchar(100) DEFAULT NULL,
  PRIMARY KEY (sID)
);
CREATE INDEX im_message_fid on im_message(fid);
CREATE INDEX im_message_tid on im_message(tid);
CREATE INDEX im_message_state on im_message(state);
CREATE INDEX im_message_stype on im_message(stype);
COMMENT ON COLUMN im_message.favatar IS '发送人头像';
COMMENT ON COLUMN im_message.fusername IS '发送人昵称';
COMMENT ON COLUMN im_message.fid IS '发送人ID';
COMMENT ON COLUMN im_message.content IS '消息内容';
COMMENT ON COLUMN im_message.tavatar IS '目标头像';
COMMENT ON COLUMN im_message.tname IS '目标名称';
COMMENT ON COLUMN im_message.tsign IS '对方签名';
COMMENT ON COLUMN im_message.stype IS '消息类型';
COMMENT ON COLUMN im_message.tusername IS '目标昵称';
COMMENT ON COLUMN im_message.state IS '状态';
COMMENT ON COLUMN im_message.stime IS '时间';
COMMENT ON COLUMN im_message.groupname IS '群组名称';
COMMENT ON COLUMN im_message.tid IS '目标ID';

CREATE OR REPLACE VIEW news_tables AS 
select a.SID AS SID,a.VERSION AS VERSION,a.FNEWSTITLE AS FNEWSTITLE,a.FSTATE AS FSTATE,a.FPEOPLE AS FPEOPLE,
a.FTIME AS FTIME,a.FOPENSCOPE AS FOPENSCOPE,b.NEWS_NUMBER AS NEWS_NUMBER,b.NEWS_PERSON AS NEWS_PERSON,
b.YETPERSON AS YETPERSON,a.FOPENSCOPEID AS FOPENSCOPEID 
from cyea_news_release a left join cyea_news_count b on a.SID = b.NEWS_RELEASEID;

CREATE OR REPLACE VIEW sa_loginlog_view AS 
select t.SID AS sid,a.SNAME AS sname,a.SCODE AS scode,a.SFNAME AS sfname,
t.SLOGINIP AS sloginip,t.SLOGINTIME AS slogintime,b.SMOBILEPHONE AS smobilephone,
t.VERSION AS version from sa_loginlog t join sa_oporg a on t.SUSERID = a.SPERSONID
join sa_opperson b 
on b.SID = a.SPERSONID;

CREATE OR REPLACE VIEW sa_onlineinfo_view AS 
select t.SID AS sid,a.SNAME AS sname,a.SCODE AS scode,a.SFNAME AS sfname,
t.SLOGINIP AS sloginip,t.SLOGINDATE AS slogindate,b.STITLE AS STITLE,
b.SMOBILEPHONE AS smobilephone,t.SSESSIONID AS ssessionid,t.SSERVICEIP AS sserviceip,
t.VERSION AS version 
from sa_onlineinfo t join sa_oporg a on  t.SUSERID = a.SPERSONID
	  join sa_opperson b 
	  on b.SID = a.SPERSONID;

CREATE OR REPLACE VIEW sa_opmobilelog_view AS 
select distinct p.SID AS sid,p.SCODE AS scode,p.SNAME AS sname,o.SFNAME AS sfname,
p.SMOBILEPHONE AS smobilephone,p.VERSION AS version 
from sa_opmobilelog l 
join sa_oporg o on o.SPERSONID = l.SUSERID 
join sa_opperson p on p.SID = l.SUSERID;

CREATE OR REPLACE VIEW sa_oporg_recycled AS 
select o.SID AS sID,o.SPARENT AS sParent,o.SCODE AS sCode,
o.SNAME AS sName,COALESCE(o.SORGKINDID,'org') AS sOrgKindID,o.SFID AS sFID,
o.SVALIDSTATE AS sValidState,o.SFCODE AS SFCODE,o.SFNAME AS sFName,
o.SSEQUENCE AS sSequence,o.SDESCRIPTION AS SDESCRIPTION,o.SADDRESS AS SADDRESS,
o.VERSION AS version from sa_oporg o where (o.SVALIDSTATE = -(1)) 
union all 
select p.SID AS sID,t.SID AS sParent,p.SCODE AS sCode,p.SNAME AS sName,'psm' AS sOrgKindID,
concat(t.SFID,'/',p.SID) AS sfid,t.SVALIDSTATE AS sValidState,
concat(t.SFCODE,'/',p.SCODE) AS sfcode,
concat(t.SFNAME,'/',p.SNAME) AS sfname,
t.SSEQUENCE AS sSequence,t.SDESCRIPTION AS SDESCRIPTION,
t.SADDRESS AS SADDRESS,p.VERSION AS version 
from sa_opperson p left join sa_oporg t on p.SMAINORGID = t.SID 
where p.SMAINORGID is not null and p.SVALIDSTATE = -1;

CREATE OR REPLACE VIEW sa_oporg_view AS 
select o.SID AS sID,o.SPARENT AS sParent,o.SCODE AS sCode,o.SNAME AS sName,
COALESCE(o.SORGKINDID,'org') AS sOrgKindID,o.SFID AS sFID,o.SVALIDSTATE AS sValidState,
o.SFCODE AS SFCODE,o.SFNAME AS sFName,o.SSEQUENCE AS sSequence,o.SDESCRIPTION AS SDESCRIPTION,
o.SADDRESS AS SADDRESS,'' AS smobilephone,o.VERSION AS version 
from sa_oporg o where ((o.SVALIDSTATE = 1) and (o.SORGKINDID <> 'psm')) 
union all 
select p.SID AS sID,t.SID AS sParent,p.SCODE AS sCode,p.SNAME AS sName,'psm' AS sOrgKindID,
concat(t.SFID,'/',p.SID) AS sfid,t.SVALIDSTATE AS sValidState,
concat(t.SFCODE,'/',p.SCODE) AS sfcode,
concat(t.SFNAME,'/',p.SNAME) AS sfname,(t.SLEVEL + p.SSEQUENCE) AS sSequence,
t.SDESCRIPTION AS SDESCRIPTION,t.SADDRESS AS SADDRESS,COALESCE(p.SMOBILEPHONE,'') AS smobilephone,p.VERSION AS version 
from sa_opperson p left join sa_oporg t on p.SMAINORGID = t.SID 
where p.SMAINORGID is not null and t.SVALIDSTATE = 1 and p.SVALIDSTATE = 1;

CREATE OR REPLACE VIEW sa_task_monitor AS 
select t.SID AS SID,t.SPARENTID AS SPARENTID,t.SNAME AS SNAME,t.SCONTENT AS SCONTENT,
t.SREMARK AS SREMARK,t.SFLOWID AS SFLOWID,t.STYPEID AS STYPEID,t.STYPENAME AS STYPENAME,
t.SIMPORTANCEID AS SIMPORTANCEID,t.SIMPORTANCENAME AS SIMPORTANCENAME,t.SEMERGENCYID AS SEMERGENCYID,
t.SEMERGENCYNAME AS SEMERGENCYNAME,t.SPROCESS AS SPROCESS,t.SACTIVITY AS SACTIVITY,
t.SCREATETIME AS SCREATETIME,t.SDISTRIBUTETIME AS SDISTRIBUTETIME,t.SLASTMODIFYTIME AS SLASTMODIFYTIME,
t.SWARNINGTIME AS SWARNINGTIME,t.SLIMITTIME AS SLIMITTIME,t.SESTARTTIME AS SESTARTTIME,
t.SEFINISHTIME AS SEFINISHTIME,t.SASTARTTIME AS SASTARTTIME,t.SAFINISHTIME AS SAFINISHTIME,
t.SEXECUTETIME AS SEXECUTETIME,t.SCPERSONID AS SCPERSONID,t.SCPERSONNAME AS SCPERSONNAME,
t.SCDEPTID AS SCDEPTID,t.SCDEPTNAME AS SCDEPTNAME,t.SCOGNID AS SCOGNID,t.SCOGNNAME AS SCOGNNAME,
t.SEPERSONID AS SEPERSONID,t.SEPERSONNAME AS SEPERSONNAME,t.SEDEPTID AS SEDEPTID,
t.SEDEPTNAME AS SEDEPTNAME,t.SEOGNID AS SEOGNID,t.SEOGNNAME AS SEOGNNAME,t.SCUSTOMERID AS SCUSTOMERID,
t.SCUSTOMERNAME AS SCUSTOMERNAME,t.SPROJECTID AS SPROJECTID,t.SPROJECTNAME AS SPROJECTNAME,
t.SPLANID AS SPLANID,t.SPLANNAME AS SPLANNAME,t.SVARIABLE AS SVARIABLE,t.SFAKE AS SFAKE,
t.SACTIVE AS SACTIVE,t.SLOCK AS SLOCK,t.SSTATUSID AS SSTATUSID,t.SSTATUSNAME AS SSTATUSNAME,
t.VERSION AS VERSION,t.SAIID AS SAIID,t.SCATALOGID AS SCATALOGID,t.SKINDID AS SKINDID,
t.SAIACTIVE AS SAIACTIVE,t.SAISTATUSID AS SAISTATUSID,t.SAISTATUSNAME AS SAISTATUSNAME,
t.SSOURCEID AS SSOURCEID,t.SCURL AS SCURL,t.SEURL AS SEURL,t.SEXECUTEMODE AS SEXECUTEMODE,
t.SEXECUTEMODE2 AS SEXECUTEMODE2,t.SPREEMPTMODE AS SPREEMPTMODE,t.SSEQUENCE AS SSEQUENCE,
t.SCPERSONCODE AS SCPERSONCODE,t.SCPOSID AS SCPOSID,t.SCPOSCODE AS SCPOSCODE,
t.SCPOSNAME AS SCPOSNAME,t.SCDEPTCODE AS SCDEPTCODE,t.SCOGNCODE AS SCOGNCODE,
t.SCFID AS SCFID,t.SEPERSONCODE AS SEPERSONCODE,t.SEPOSID AS SEPOSID,t.SEPOSCODE AS SEPOSCODE,
t.SEPOSNAME AS SEPOSNAME,t.SEDEPTCODE AS SEDEPTCODE,t.SEOGNCODE AS SEOGNCODE,t.SEFID AS SEFID,
t.SEXECUTORNAMES AS SEXECUTORNAMES,t.SRESPONSIBLE AS SRESPONSIBLE,t.SCUSTOMERCODE AS SCUSTOMERCODE,
t.SPROJECTCODE AS SPROJECTCODE,t.SPLANCODE AS SPLANCODE,t.SDATA1 AS SDATA1,t.SDATA2 AS SDATA2,
t.SDATA3 AS SDATA3,t.SDATA4 AS SDATA4,t.SWORKTIME AS SWORKTIME,t.SCFNAME AS SCFNAME,
t.SEFNAME AS SEFNAME,t.SHINTS AS SHINTS,t.SSHORTCUT AS SSHORTCUT,t.SFRONTID AS SFRONTID,
t.SFMAKERNAME AS SFMAKERNAME,p.SNAME AS sflowName 
from sa_task t join sa_task p on t.SID = p.SPARENTID and t.SFLOWID = t.SID;

CREATE OR REPLACE VIEW sa_vpnlog_view AS 
select distinct o.SID AS sid,o.SCODE AS scode,o.SNAME AS sname,o.SFNAME AS sfname,o.VERSION AS version,
l.SLOGINTIME AS slogintime from (sa_loginlog l join sa_oporg o on o.SPERSONID = l.SUSERID) 
where ((l.SLOGINIP = 'x.x.x.x') and (o.SID is not null) 
	   and (not(exists(select p.SUSERID from sa_opmobilelog p where (l.SUSERID = p.SUSERID)))) 
and (l.SLOGINTIME = (select max(lg.SLOGINTIME) from sa_loginlog lg where (lg.SUSERID = l.SUSERID)))) 
order by l.SLOGINTIME desc;

INSERT INTO sa_docnamespace VALUES ('defaultDocNameSpace', '文档中心', '127.0.0.1', '8080', 'http://127.0.0.1:8080/DocServer', '37', '1', '0');
INSERT INTO sa_docnode VALUES ('root', null, '文档中心', '', null, 'dir', '/root', '/文档中心', '', '', '', null, '', '', '', '', '', '', null, '', '', null, '4', '', '', '', null, 'defaultDocNameSpace', '', '', '1');
INSERT INTO sa_opmanagetype VALUES ('systemManagement', '系统管理', 'systemManagement', 'ogn', ' 机构 部门 岗位 工作组 人员', null, null, '2');
INSERT INTO sa_oporg VALUES ('ORG01', '管理员', 'TULIN', '', '/管理员', '/TULIN', '/ORG01.ogn', 'ogn', '1', null, '1', '', '', '', '', '', '', '', '16', '', '96');
INSERT INTO sa_oporg VALUES ('PSN01@ORG01', 'system', 'SYSTEM', '', '/管理员/system', '/TULIN/SYSTEM', '/ORG01.ogn/PSN01@ORG01.psm', 'psm', '1', 'ORG01', '2', '', '', '', '', '', 'PSN01', 'nkLeaf', '15', '', '1');
INSERT INTO sa_opauthorize(SID, SORGID, SORGNAME, SORGFID, SORGFNAME, SAUTHORIZEROLEID, SDESCRIPTION, SCREATORFID, SCREATORFNAME, SCREATETIME, VERSION, SROLELEVEL)VALUES('AHR01', 'PSN01@ORG01', '管理员', '/ORG01.ogn/PSN01@ORG01.psm', '/管理员/system', 'RL01', '超级管理员', '/ORG01.ogn/PSN01@ORG01.psm', '/管理员/system', '2009/11/3', 0, '0');
INSERT INTO sa_oppermission VALUES ('01B955F5829F44219FB2806797B45A3B', 'RL01', '/OA/doc/process/baseCode/docSecretLevel/docSecretLevelProcess', '/其它/基础设置/公文密级', 'docSecretLevelActivity', '', '', '', '0', '', null, '1', '0');
INSERT INTO sa_oppermission VALUES ('098A9455CDDD44299140A281D3DE875F', 'RL01', '/OA/doc/process/baseCode/docExigenceLevel/docExigenceLevelProcess', '/其它/基础设置/公文紧急程度', 'docExigenceLevelActivity', '', '', '', '0', '', null, '1', '0');
INSERT INTO sa_oppermission VALUES ('182217CC50E84AB2A6EA3085A18BA621', 'RL01', '/SA/doc/docSetting/docSettingProcess', '/系统管理/文档/文档配置', 'mainActivity', '', '', '', '0', '', null, '1', '0');
INSERT INTO sa_oppermission VALUES ('1B1AF2E6140A445796ABE0442CBB54DE', 'RL01', '/SA/doc/docPermission/docPermissionProcess', '/系统管理/文档/文档关联', 'mainActivity', '', '', '', '0', '', null, '1', '0');
INSERT INTO sa_oppermission VALUES ('1F4272327EEF446B8005AEB1C1A42E0B', 'RL01', '/SA/OPM/authorization/authorizationProcess', '/系统管理/组织权限/授权管理-分级', 'gradeActivity', '', '', '', '0', '', null, '1', '1');
INSERT INTO sa_oppermission VALUES ('265569FC504443E1B134592E3B5FCC5C', 'RL01', '/SA/OPM/log/logProcess', '/系统管理/组织权限/组织机构日志', 'mainActivity', '', '', '', '0', '', null, '1', '1');
INSERT INTO sa_oppermission VALUES ('3566316F52F84896ACE1EF9BF42018BE', 'RL01', '/SA/OPM/organization/organizationProcess', '/系统管理/组织权限/组织管理', 'mainActivity', '', '', '', '0', '', null, '1', '1');
INSERT INTO sa_oppermission VALUES ('38A312285E834995AFCAC32E2D50265A', 'RL01', '/SA/doc/docCenter/docCenterProcess', '/系统管理/文档/文档中心', 'docCenter', '', '', '', '0', '', null, '1', '0');
INSERT INTO sa_oppermission VALUES ('3B051D390A7B4426B2663AE27F3A45A8', 'RL01', '/OA/docrs/process/baseCode/docRedHead/docRedHeadProcess', '/其它/红头维护', 'mainActivity', '', '', '', '0', '', null, '1', '1');
INSERT INTO sa_oppermission VALUES ('5F62DE289C8648689D20D9370ACAE21C', 'RL01', '/SA/OPM/role/roleProcess', '/系统管理/组织权限/角色管理', 'mainActivity', '', '', '', '0', '', null, '1', '1');
INSERT INTO sa_oppermission VALUES ('660E9AF723874169A20E80C50B6D6C04', 'RL01', '/OA/docrs/process/docArchive/docArchiveProcess', '/其它/公文归档查询', 'mainActivity', '', '', '', '0', '', null, '1', '2');
INSERT INTO sa_oppermission VALUES ('6A02EEF862114421A0EC8BD3A4BD4222', 'RL01', '/SA/OPM/authorization/authorizationProcess', '/系统管理/组织权限/授权管理', 'mainActivity', '', '', '', '0', '', null, '1', '1');
INSERT INTO sa_oppermission VALUES ('6F21B10EAECC46BE95A7A9349D0B041F', 'RL01', '/SA/OPM/grade/gradeProcess', '/系统管理/组织权限/分级管理', 'mainActivity', '', '', '', '0', '', null, '1', '1');
INSERT INTO sa_oppermission VALUES ('7A17C36CD1EF4DC1A8C42B805A716556', 'RL01', '/OA/softwareDownLoad/process/software/softwareProcess', '/文件共享/目录维护', 'staticActivity1', '', '', '', '0', '', null, '1', '0');
INSERT INTO sa_oppermission VALUES ('82E555A346274CE092AE25B4DD0BFBE8', 'RL01', '/SA/log/logProcess', '/系统管理/系统工具/操作日志', 'mainActivity', '', '', '', '0', '', null, '1', '1');
INSERT INTO sa_oppermission VALUES ('84EBC08BB9D64F4092267873339FBEE2', 'RL01', '/SA/OPM/repairTools/repairToolsProcess', '/系统管理/组织权限/修复工具', 'mainActivity', '', '', '', '0', '', null, '1', '1');
INSERT INTO sa_oppermission VALUES ('851787396B3E4D3092B05A8B113131DD', 'RL01', '/OA/softwareDownLoad/process/software/softwareProcess', '/文件共享/目录维护', 'mainActivity', '', '', '', '0', '', null, '1', '1');
INSERT INTO sa_oppermission VALUES ('9D8D492C5D49460E9DDA5F6CED4B1545', 'RL01', '/SA/update/updateProcess', '/系统管理/系统工具/软件更新', 'mainActivity', '', '', '', '0', '', null, '1', '1');
INSERT INTO sa_oppermission VALUES ('9DC6B147AC1F478E9DFE5199F4EC8BCF', 'RL01', '/SA/online/onlineProcess', '/系统管理/系统工具/在线用户分级', 'gradeOnlineUserActivity', '', '', '', '0', '', null, '1', '6');
INSERT INTO sa_oppermission VALUES ('A84780D2CEF64C5B9DE9947ECD13ED28', 'RL01', '/SA/doc/docSearch/docSearchProcess', '/系统管理/文档/文档检索', 'mainActivity', '', '', '', '0', '', null, '1', '0');
INSERT INTO sa_oppermission VALUES ('AC305CCADA8D4947849F0E4F539077B0', 'RL01', '/OA/docrs/process/setReceiveDocTemplate/setReceiveDocTemplateProcess', '/其它/收发文基础设置/设置收发文模版', 'mainActivity', '', '', '', '0', '', null, '1', '2');
INSERT INTO sa_oppermission VALUES ('AD0706B27A22492BA4E979D5DF5CD2AA', 'RL01', '/OA/docrs/process/baseCode/docType/docTypePrecess', '/其它/收发文基础设置/设置公文类别', 'mainActivity', '', '', '', '0', '', null, '1', '2');
INSERT INTO sa_oppermission VALUES ('BCBEB3FEA6DB4283AD2494254FDBCDAE', 'RL01', '/SA/online/onlineProcess', '/系统管理/系统工具/在线用户', 'mainActivity', '', '', '', '0', '', null, '1', '3');
INSERT INTO sa_oppermission VALUES ('C6914BAA2E84424C901DBF8FD95144D7', 'RL01', '/SA/OPM/management/managementProcess', '/系统管理/组织权限/业务管理权限', 'mainActivity', '', '', '', '0', '', null, '1', '1');
INSERT INTO sa_oppermission VALUES ('C6B3C40F53200001F12719F019995DA0', 'RL01', '/SA/OPM/recycled/recycledProcess', '/系统管理/组织机构/回收站', 'mainActivity', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C72FB49C224000015E2927B019E010D9', 'RL01', '/OA/Report/reportImgShowProcess', '/统计报表/时间维度统计图表展示', 'mainActivity', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C72FF32DC44000015C101BD21A0010B4', 'RL01', '/OA/Report/UserCountByCounty/usercountbycountyProcess', '/统计报表/各县系统用户统计', 'mainActivity', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C73002B742B000017654CC60934013C6', 'RL01', '/OA/Report/personusedayReport/mainActivityProcess', '/统计报表/用户使用系统时间统计', 'mainActivity', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C7304519F47000017F591F2B1FD6EB50', 'RL01', '/OA/Report/OnlineInfoCountOnWeek/mainActivityProcess', '/统计报表/按在线用户量统计', 'mainActivity', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C7304EB047300001DED41F75D51012B9', 'RL01', '/OA/Report/ConcurrentOnDay/mainActivityProcess', '/统计报表/天内并发量统计', 'mainActivity', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C7305130B87000018EA718841EB06700', 'RL01', '/OA/Report/UserIncrement/userincrementProcess', '/统计报表/用户增长量统计', 'mainActivity', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C7305169AE000001C7741ACC284019D3', 'RL01', '/OA/log/LoginLogProcess', '/系统管理/系统工具/用户登录统计', 'LoginLog', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C7305169AED0000167D26C507440DE00', 'RL01', '/SA/log/mobileAppLogProcess', '/系统管理/系统工具/手机用户统计', 'mobileAppLog', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C7305169AF800001EA2316506D70FAF0', 'RL01', '/SA/log/VPNLogProcess', '/系统管理/系统工具/VPN用户统计', 'VPNLog', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C7305169B1900001B9731A801F5D9020', 'RL01', '/SA/MobileNumber/MobileNumbersProcess', '/系统管理/系统工具/移动号码段维护', 'MobileNumbers', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C73052FED5200001504DBB4012607480', 'RL01', '/OA/Report/RecvFileCountOnWeek/mainActivityProcess', '/统计报表/周来文登记数统计', 'mainActivity', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C73053D2C5B000017ACC110014DC1EDD', 'RL01', '/OA/Report/SendFileCountOnWeek/mainActivityProcess', '/统计报表/周发文数统计', 'mainActivity', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C73054DDF8700001A473530D17AF1669', 'RL01', '/OA/Report/RecvFileCountByMonth/mainActivityProcess', '/统计报表/按月收文登记数统计', 'mainActivity', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C730560A70B00001914298E4E92056A0', 'RL01', '/OA/Report/SendFileCountByMonth/mainActivityProcess', '/统计报表/按月发文数统计', 'mainActivity', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C73058D190100001504B2A1B59C01545', 'RL01', '/OA/Report/RecvFileCountByMonth/reportAllActivityProcess', '/统计报表/收文登记数统计', 'mainActivity', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C73059667980000122D8187815D01037', 'RL01', '/OA/Report/SendFileCountByMonth/reportAllActivityProcess', '/统计报表/发文数统计', 'mainActivity', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C730989BF62000012D6E164C164082F0', 'RL01', '/OA/Report/RecvFileCountByMonth/reportProcess', '/统计报表/收文数据对比', 'reportLineActivity', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C730989BF7400001AC5C1EF079D02590', 'RL01', '/OA/Report/SendFileCountByMonth/reportProcess', '/统计报表/发文数据对比', 'reportLineActivity', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C731F08F25A00001934520F0BE70F700', 'RL01', '/OA/ShortMessage/process/SendMsgFromSystem/sendMsgFromSystemProcess', '/发送短信/从系统通讯录发短信', 'mainActivity', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C731F08F2A80000183FC1B434C5818AA', 'RL01', '/OA/ShortMessage/process/SendMsgQuery/sendMsgQueryProcess', '/发送短信/已发短信查询', 'mainActivity', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C7362262EE800001931710941E606820', 'RL01', '/OA/personal/process/personalInfo/personalProcess', '/其它/个人痕迹查询', 'markActivity', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C79092E0D2C00001FFD6E8A61810C900', 'RL01', '/OA/hr/wage/ListActivityPersonProcess', '/其它/个人薪资查询', 'mainActivity', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C7A4DAEE8A500001ADED569E1537A090', 'RL01', '/OA/docrs/process/sendDoc/AllSendedProcess', '/其它/已发文件', 'AllSendedActivity', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C7A5BEC63EE0000123FA2804F3571E8B', 'RL01', '/OA/CheckWorkAtten/baseProcess', '/工作管理/考勤管理/上班时间设置', 'workDateActivity', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C7B2671830000001A63111A019609FA0', 'RL01', '/OA/Project/Manage/mainProcess', '/州级项目审批情况/项目审批情况统计', 'mainActivity', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C7B2F1D86D00000168DBE4C02B1013E2', 'RL01', '/OA/OfficeOperation/registerProcess', '/(办件)运行情况/办件运行情况登记(州内)', 'mainActivity', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C7B2F53FD6A0000169FDDF90149019F0', 'RL01', '/OA/OfficeOperation/registerProcess', '/(办件)运行情况/办件运行情况查看(州内)', 'lookActivity', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C7B2F53FD8C00001BC5C1F901078EE00', 'RL01', '/OA/OfficeOperation/registerProcess', '/(办件)运行情况/办件运行情况登记(州外)', 'mainActivity1', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C7B2F53FDB3000019EF0141B73404B10', 'RL01', '/OA/OfficeOperation/registerProcess', '/(办件)运行情况/办件运行情况查看(州外)', 'lookActivity1', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C7D8FEE6EFE00001B6751A1E12303070', 'RL01', '/OA/fawenDanwei/mainProcess', '/系统管理/系统工具/允许发文单位', 'mainActivity', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C82E3F2608B00001E83E18231E2A18BA', 'RL01', '/SA/theme/bgProcess', '/系统管理/系统工具/登录页背景配置', 'mainActivity', '', '', '', null, '', null, null, '1');
INSERT INTO sa_oppermission VALUES ('C8336D112D0000013CE01830EDF01F56', 'RL01', '/OA/workLog/WorkLogProcess', '/工作台账管理/工作日志/填写工作日志', 'myWorkLog', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C8336D112E7000016B60624914781E9A', 'RL01', '/OA/workLog/WorkLogProcess', '/工作台账管理/工作日志/我的工作日志', 'MyWorklogList', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C8336D112FE00001DDAFA0612340187E', 'RL01', '/OA/workLog/WorkLogProcess', '/工作台账管理/工作日志/工作日志审批', 'waitWorkLog', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C8336D1131300001CB7E1FF017531313', 'RL01', '/OA/workLog/WorkLogProcess', '/工作台账管理/工作日志/工作日志汇总', 'allWorklogList', '', '', '', null, '', null, null, '0');
INSERT INTO sa_oppermission VALUES ('C8373BC0E94000011694194017001AE0', 'RL01', '/OA/CheckWorkAtten/personnelProcess', '/考勤管理/个人考勤', 'personnelActivity', '', '', '', null, '', null, null, '1');
INSERT INTO sa_oppermission VALUES ('C8373BC0EB8000013B42146CBC7010F0', 'RL01', '/OA/CheckWorkAtten/personnelProcess', '/考勤管理/考勤记录', 'DayChekinList', '', '', '', null, '', null, null, '1');
INSERT INTO sa_oppermission VALUES ('C8373BC0EE1000011C8215C05B15EFB0', 'RL01', '/OA/CheckWorkAtten/personnelProcess', '/考勤管理/考勤统计', 'reportActivity', '', '', '', null, '', null, null, '1');
INSERT INTO sa_oppermission VALUES ('C8A5A0B5BED00001ADC31CC0968311E8', 'RL01', 'SA/services/pcProcess', '/系统管理/系统工具/服务器监控', 'mainActivity', '', '', '', null, '', null, null, '1');
INSERT INTO sa_oppermission VALUES ('C8D3540ADE800001392115941C10100B', 'RL01', '/OA/docrs/process/sendDoc/sendDocProcess', '/发文管理/删除发文', 'SendDel', '', '', '', null, '', null, null, '1');
INSERT INTO sa_oppermission VALUES ('C8DC2295A8E00001B8DE85203AD016AE', 'RL01', '/SA/task/taskCenter/process', '/任务中心/任务列表', 'mainActivity', '', '', '', null, '', null, null, '1');
INSERT INTO sa_oppermission VALUES ('C8DC2295A9600001BBE919691C301C37', 'RL01', '/SA/process/monitor/process', '/任务中心/流程监控', 'mainActivity', '', '', '', null, '', null, null, '1');
INSERT INTO sa_oppermission VALUES ('C8DC2295A9E00001D89590F5198012BC', 'RL01', '/SA/task/unFlowmana/process', '/任务中心/任务处理', 'mainActivity', '', '', '', null, '', null, null, '1');
INSERT INTO sa_oppermission VALUES ('C8DC2295AA6000017BF83A6965004D50', 'RL01', '/flw/dwr/process', '/任务中心/流程设计', 'vml-dwr-editer', '', '', '', null, '', null, null, '1');
INSERT INTO sa_oppermission VALUES ('C94E5AE783D000017BE612A0165419DF', 'RL01', '029AB9CC9C5D4378B25C9BCB6C32B33D', '/采购管理/采购登记', 'bizActivity2', null, null, null, null, null, null, null, '1');
INSERT INTO sa_oppermission VALUES ('C94E5AE784A0000163C271C810651321', 'RL01', '029AB9CC9C5D4378B25C9BCB6C32B33D', '/采购管理/采购审批', 'bizActivity4', null, null, null, null, null, null, null, '1');
INSERT INTO sa_oppermission VALUES ('C94EE9000440000135A1A7F050121CA8', 'RL01', '/SA/task/taskCenter/process', '/任务中心/流程监控', 'monitorActivity', null, null, null, null, null, null, null, '1');
INSERT INTO sa_oppermission VALUES ('C94EE9000540000138D11EF078DC6810', 'RL01', '/SA/task/taskCenter/process', '/任务中心/任务处理', 'unFlowmanaActivity', null, null, null, null, null, null, null, '1');
INSERT INTO sa_oppermission VALUES ('C94EE90006D000013BDE12401F401700', 'RL01', '/SA/task/taskCenter/process', '/任务中心/系统提醒', 'reminActivity', null, null, null, null, null, null, null, '1');
INSERT INTO sa_oppermission VALUES ('C94F4E969D600001886F19D05E501F55', 'RL01', '/SA/OPM/recycled/recycledProcess', '/系统管理/组织机构/回收站-分级', 'gradeRecycledActivity', null, null, null, null, null, null, null, '1');
INSERT INTO sa_oppermission VALUES ('D0EC487F72FF4D768C92520A8B90F458', 'RL01', '/OA/docrs/process/baseCode/docArchiveTree/docArchiveTreePrecess', '/其它/收发文基础设置/设置公文归档', 'mainActivity', '', '', '', '0', '', null, '1', '2');
INSERT INTO sa_oppermission VALUES ('E6D1673C76174CCEA9919C0C16453C98', 'RL01', '/SA/OPM/management/managementProcess', '/系统管理/组织权限/业务管理权限-分级', 'gradeActivity', '', '', '', '0', '', null, '1', '1');
INSERT INTO sa_oppermission VALUES ('EE9E19F50356498C96BB193356F8AF38', 'RL01', '/SA/OPM/organization/organizationProcess', '/系统管理/组织权限/组织管理-分级', 'gradeActivity', '', '', '', '0', '', null, '1', '1');
INSERT INTO sa_oppermission VALUES ('EF8F1CC8AB6F4728A7D083B6DD1790C1', 'RL01', '/OA/docrs/process/setReceiveDocTemplate/setReceiveDocTemplateProcess', '/其它/收发文基础设置/设置映射关系', 'SetORMstaticActivity', '', '', '', '0', '', null, '1', '0');
INSERT INTO sa_oppermission VALUES ('F2AF3284E2D6405E9990376C19C57D45', 'RL01', '/SA/OPM/agent/agentProcess', '/系统管理/组织权限/代理设置', 'mainActivity', '', '', '', '0', '', null, '1', '1');
INSERT INTO sa_opperson VALUES ('PSN01', 'system', 'SYSTEM', '', '1', '管理员', 'C4CA4238A0B923820DCC509A6F75849B', '120', '2013-10-20', 'ORG01', '', '1', '1', '', '男', '1976-12-03', '2006-06-06', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '14769660886', '', '', '4', null, '', '', '', '', '', '', '','',null);
INSERT INTO sa_oprole VALUES ('RL01', '超级管理员', 'opm', '勿删-系统应用', 'fun', '', '', '0', '1', '4');
INSERT INTO sa_oprole VALUES ('RL02', '任务', 'task', '系统管理', 'fun', '', '', '0', '1', '2');
INSERT INTO sa_oprole VALUES ('RL02-doc', '文档', 'doc', '系统管理', 'fun', '', '', '0', '1', '2');
INSERT INTO sa_flowfolder VALUES ('root', null, '根目录', 'root', '根目录', null, '/D08B63947EE1444D8C97DC0C5EAD8AD6', '/根目录', '/root', 0);
